@@ -186,85 +186,94 @@ test_that("scientificName basic use works - no synonyms", {
 ######### geometry inputs work as expected
 test_that("geometry inputs work as expected", {
   skip_on_cran() # because fixture in .Rbuildignore
-  vcr::use_cassette("occ_data_geometry", {
-
-    # in well known text format
+  
+  # in well known text format
+  vcr::use_cassette("occ_data_geometry_aa", {
     aa <- occ_data(geometry='POLYGON((30.1 10.1,40 40,20 40,10 20,30.1 10.1))', limit=20)
-    expect_is(aa, "gbif_data")
-    expect_is(unclass(aa), "list")
-    expect_named(attr(aa, "args"), c('limit', 'offset', 'geometry'))
-    expect_gt(NROW(aa$data), 0)
-
-    # with a taxon key
+  }, preserve_exact_body_bytes = TRUE)
+  
+  expect_is(aa, "gbif_data")
+  expect_is(unclass(aa), "list")
+  expect_named(attr(aa, "args"), c('limit', 'offset', 'geometry'))
+  expect_gt(NROW(aa$data), 0)
+  
+  # with a taxon key
+  vcr::use_cassette("occ_data_geometry_bb", {
     key <- 3189815
-    bb <- occ_data(taxonKey = key, geometry='POLYGON((30.1 10.1,40 40,20 40,10 20,30.1 10.1))',
-                     limit=20)
-    expect_is(bb, "gbif_data")
-    expect_is(unclass(bb), "list")
-    expect_named(attr(bb, "args"), c('limit', 'offset', 'taxonKey', 'geometry'))
-    expect_gt(NROW(bb$data), 0)
+    bb <- occ_data(taxonKey = key, 
+      geometry='POLYGON((30.1 10.1,40 40,20 40,10 20,30.1 10.1))',
+      limit=20)
+  }, preserve_exact_body_bytes = TRUE)
 
-    # using bounding box, converted to WKT internally
+  expect_is(bb, "gbif_data")
+  expect_is(unclass(bb), "list")
+  expect_named(attr(bb, "args"), c('limit', 'offset', 'taxonKey', 'geometry'))
+  expect_gt(NROW(bb$data), 0)
+    
+  # using bounding box, converted to WKT internally
+  vcr::use_cassette("occ_data_geometry_cc", {
     cc <- occ_data(geometry=c(-125.0,38.4,-121.8,40.9), limit=20)
-    expect_is(cc, "gbif_data")
-    expect_is(unclass(cc), "list")
-    expect_named(attr(cc, "args"), c('limit', 'offset', 'geometry'))
-    expect_gt(NROW(cc$data), 0)
-    expect_equal(NROW(cc$data), NROW(aa$data))
+  }, preserve_exact_body_bytes = TRUE)
 
-    # Search on a long WKT string - too long for a GBIF search API request
-    ## internally convert WKT string to a bounding box
-    wkt <- "POLYGON((13.26349675655365 52.53991761181831,18.36115300655365 54.11445544219924,
-    21.87677800655365 53.80418956368524,24.68927800655365 54.217364774722455,28.20490300655365
-    54.320018299365124,30.49005925655365 52.85948216284084,34.70880925655365 52.753220564427814,
-    35.93927800655365 50.46131871049754,39.63068425655365 49.55761261299145,40.86115300655365
-    46.381388009130845,34.00568425655365 45.279102926537,33.30255925655365 48.636868465271846,
-    30.13849675655365 49.78513301801265,28.38068425655365 47.2236377039631,29.78693425655365
-    44.6572866068524,27.67755925655365 42.62220075124676,23.10724675655365 43.77542058000212,
-    24.51349675655365 47.10412345120368,26.79865300655365 49.55761261299145,23.98615300655365
-    52.00209943876426,23.63459050655365 49.44345313705238,19.41584050655365 47.580567827212114,
-    19.59162175655365 44.90682206053508,20.11896550655365 42.36297154876359,22.93146550655365
-    40.651849782081555,25.56818425655365 39.98171166226459,29.61115300655365 40.78507856230178,
-    32.95099675655365 40.38459278067577,32.95099675655365 37.37491910393631,26.27130925655365
-    33.65619609886799,22.05255925655365 36.814081996401605,18.71271550655365 36.1072176729021,
-    18.53693425655365 39.16878677351903,15.37287175655365 38.346355762190846,15.19709050655365
-    41.578843777436326,12.56037175655365 41.050735748143424,12.56037175655365 44.02872991212046,
-    15.19709050655365 45.52594200494078,16.42755925655365 48.05271546733352,17.48224675655365
-    48.86865641518059,10.62677800655365 47.817178329053135,9.57209050655365 44.154980365192,
-    8.16584050655365 40.51835445724746,6.05646550655365 36.53210972067291,0.9588092565536499
-    31.583640057148145,-5.54509699344635 35.68001485298146,-6.77556574344635 40.51835445724746,
-    -9.41228449344635 38.346355762190846,-12.40056574344635 35.10683619158607,-15.74040949344635
-    38.07010978950028,-14.68572199344635 41.31532459432774,-11.69744074344635 43.64836179231387,
-    -8.88494074344635 42.88035509418534,-4.31462824344635 43.52103366008421,-8.35759699344635
-    47.2236377039631,-8.18181574344635 50.12441989397795,-5.01775324344635 49.55761261299145,
-    -2.73259699344635 46.25998980446569,-1.67790949344635 44.154980365192,-1.32634699344635
-    39.30493590580802,2.18927800655365 41.44721797271696,4.47443425655365 43.26556960420879,
-    2.18927800655365 46.7439668697322,1.83771550655365 50.3492841273576,6.93537175655365
-    49.671505849335254,5.00177800655365 52.32557322466785,7.81427800655365 51.67627099802223,
-    7.81427800655365 54.5245591562317,10.97834050655365 51.89375191441792,10.97834050655365
-    55.43241335888528,13.26349675655365 52.53991761181831))"
-    wkt <- gsub("\n", " ", wkt)
+  expect_is(cc, "gbif_data")
+  expect_is(unclass(cc), "list")
+  expect_named(attr(cc, "args"), c('limit', 'offset', 'geometry'))
+  expect_gt(NROW(cc$data), 0)
+  expect_equal(NROW(cc$data), NROW(aa$data))
 
-    # Default option with large WKT string fails
-    # expect_error(occ_data(geometry = wkt, limit = 1),
-    #              "Client error: \\(413\\) Request Entity Too Large")
+  # Search on a long WKT string - too long for a GBIF search API request
+  ## internally convert WKT string to a bounding box
+  wkt <- "POLYGON((13.26349675655365 52.53991761181831,18.36115300655365 54.11445544219924,
+  21.87677800655365 53.80418956368524,24.68927800655365 54.217364774722455,28.20490300655365
+  54.320018299365124,30.49005925655365 52.85948216284084,34.70880925655365 52.753220564427814,
+  35.93927800655365 50.46131871049754,39.63068425655365 49.55761261299145,40.86115300655365
+  46.381388009130845,34.00568425655365 45.279102926537,33.30255925655365 48.636868465271846,
+  30.13849675655365 49.78513301801265,28.38068425655365 47.2236377039631,29.78693425655365
+  44.6572866068524,27.67755925655365 42.62220075124676,23.10724675655365 43.77542058000212,
+  24.51349675655365 47.10412345120368,26.79865300655365 49.55761261299145,23.98615300655365
+  52.00209943876426,23.63459050655365 49.44345313705238,19.41584050655365 47.580567827212114,
+  19.59162175655365 44.90682206053508,20.11896550655365 42.36297154876359,22.93146550655365
+  40.651849782081555,25.56818425655365 39.98171166226459,29.61115300655365 40.78507856230178,
+  32.95099675655365 40.38459278067577,32.95099675655365 37.37491910393631,26.27130925655365
+  33.65619609886799,22.05255925655365 36.814081996401605,18.71271550655365 36.1072176729021,
+  18.53693425655365 39.16878677351903,15.37287175655365 38.346355762190846,15.19709050655365
+  41.578843777436326,12.56037175655365 41.050735748143424,12.56037175655365 44.02872991212046,
+  15.19709050655365 45.52594200494078,16.42755925655365 48.05271546733352,17.48224675655365
+  48.86865641518059,10.62677800655365 47.817178329053135,9.57209050655365 44.154980365192,
+  8.16584050655365 40.51835445724746,6.05646550655365 36.53210972067291,0.9588092565536499
+  31.583640057148145,-5.54509699344635 35.68001485298146,-6.77556574344635 40.51835445724746,
+  -9.41228449344635 38.346355762190846,-12.40056574344635 35.10683619158607,-15.74040949344635
+  38.07010978950028,-14.68572199344635 41.31532459432774,-11.69744074344635 43.64836179231387,
+  -8.88494074344635 42.88035509418534,-4.31462824344635 43.52103366008421,-8.35759699344635
+  47.2236377039631,-8.18181574344635 50.12441989397795,-5.01775324344635 49.55761261299145,
+  -2.73259699344635 46.25998980446569,-1.67790949344635 44.154980365192,-1.32634699344635
+  39.30493590580802,2.18927800655365 41.44721797271696,4.47443425655365 43.26556960420879,
+  2.18927800655365 46.7439668697322,1.83771550655365 50.3492841273576,6.93537175655365
+  49.671505849335254,5.00177800655365 52.32557322466785,7.81427800655365 51.67627099802223,
+  7.81427800655365 54.5245591562317,10.97834050655365 51.89375191441792,10.97834050655365
+  55.43241335888528,13.26349675655365 52.53991761181831))"
+  wkt <- gsub("\n", " ", wkt)
 
-    # if WKT too long, with 'geom_big=bbox': makes into bounding box
+  # if WKT too long, with 'geom_big=bbox': makes into bounding box
+  vcr::use_cassette("occ_data_geometry_dd", {
     dd <- occ_data(geometry = wkt, geom_big = "bbox", limit = 30)
-    expect_lt(nchar(attr(dd, "args")$geometry), nchar(wkt))
-    expect_message(occ_data(geometry = wkt, geom_big = "bbox", limit = 1),
-                   "geometry is big, querying BBOX, then pruning results to polygon")
+  }, preserve_exact_body_bytes = TRUE)
+  
+  expect_lt(nchar(attr(dd, "args")$geometry), nchar(wkt))
+  expect_message(occ_data(geometry = wkt, geom_big = "bbox", limit = 1),
+                 "geometry is big, querying BBOX, then pruning results to polygon")
 
-    # use 'geom_big=axe'
+  # use 'geom_big=axe'
+  vcr::use_cassette("occ_data_geometry_ee_gg", {
     ee <- occ_data(geometry = wkt, geom_big = "axe", limit = 30)
     ## more calls
     gg <- occ_data(geometry = wkt, geom_big = "axe", geom_size = 30, limit = 5)
 
-    expect_gt(length(names(gg)), length(names(ee)))
+    expect_gt(length(names(ee)), length(names(gg)))
+  }, preserve_exact_body_bytes = TRUE)
 
-
-
-    # bad wkt is caught and handled appropriately
+  # bad wkt is caught and handled appropriately
+  vcr::use_cassette("occ_data_geometry_errors", {
     badwkt1 <- "POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 a))"
     expect_error(occ_data(geometry = badwkt1))
 
@@ -276,7 +285,6 @@ test_that("geometry inputs work as expected", {
 
     badwkt4 <- "CIRCULARSTRING(1 5, 6 2, 7 3)"
     expect_error(occ_data(geometry = badwkt4))
-
   }, preserve_exact_body_bytes = TRUE)
 })
 
