@@ -1,6 +1,6 @@
 test_that("occ_download_wait: real request works", {
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
 
   vcr::use_cassette("occ_download_wait_request", {
     downl_req <- occ_download(pred("taxonKey", 9206251),
